@@ -82,6 +82,18 @@ sparql.rdf <- function(model, sparql) {
     return(.stringMatrix.to.matrix(stringMat))
 }
 
+sparql.remote <- function(endpoint, sparql) {
+	stringMat <- .jcall(
+			"com/github/egonw/rrdf/RJenaHelper",
+			"Lcom/github/egonw/rrdf/StringMatrix;", "sparqlRemote", endpoint, sparql
+	)
+	exception <- .jgetEx(clear = TRUE)
+	if (!is.null(exception)) {
+		stop(exception)
+	}
+	return(.stringMatrix.to.matrix(stringMat))
+}
+
 add.triple <- function(store,
 	subject="http://example.org/Subject",
 	predicate="http://example.org/Predicate",
@@ -108,6 +120,19 @@ add.data.triple <- function(store,
 	store
 }
 
+construct.rdf <- function(model, sparql) {
+	newModel <- .jcall(
+		"com/github/egonw/rrdf/RJenaHelper",
+		"Lcom/hp/hpl/jena/rdf/model/Model;",
+		"construct", model, sparql
+	)
+	exception <- .jgetEx(clear = TRUE)
+	if (!is.null(exception)) {
+		stop(exception)
+	}
+	return(newModel)
+}
+
 .stringMatrix.to.matrix <- function(stringMatrix) {
     nrows <- .jcall(stringMatrix, "I", "getRowCount")
     ncols <- .jcall(stringMatrix, "I", "getColumnCount")
